@@ -9,12 +9,12 @@ function(model,data,...) {
   
   has.tcltk <- requireNamespace("tcltk")
   if (has.tcltk) 
-    pb <- tkProgressBar("genCookDist", "Inspecting case ", 0, nrow(data))
+    pb <- tcltk::tkProgressBar("genCookDist", "Inspecting case ", 0, nrow(data))
   
   for (i in 1:nrow(data)) {
     
     if (has.tcltk) 
-      setTkProgressBar(pb, i, label = sprintf(paste("Inspecting case", i,"of",nrow(data))))
+      tcltk::setTkProgressBar(pb, i, label = sprintf(paste("Inspecting case", i,"of",nrow(data))))
     
     fit <- try(sem(model,data[-i,],...),TRUE)
     
